@@ -5,6 +5,10 @@
 """
 
 from .image import Image
+from .listinput import ListInput
+from .optionalwidget import OptionalWidget
+from .mappedcheckbox import MappedCheckBox
+from .stringornumberwidget import StringOrNumberWidget
 from .iconlabel import IconLabel
 from .flowlayout import FlowLayout
 from .colorchooserbutton import ColorChooserButton
@@ -23,6 +27,10 @@ from .selectionwidget import SelectionWidget
 from .codeeditor import CodeEditor
 
 __all__ = ["Image",
+           "ListInput",
+           "OptionalWidget",
+           "MappedCheckBox",
+           "StringOrNumberWidget",
            "IconLabel",
            "FlowLayout",
            "ColorChooserButton",
