@@ -9,4 +9,7 @@ import bidict as bdct
 class bidict(bdct.bidict):
 
     def __init__(self, *args, **kwargs):
-        super().__init__(kwargs)
+        if len(args) == 1 and isinstance(args[0], dict):
+            super().__init__(args[0])
+        else:
+            super().__init__(kwargs)
