@@ -68,11 +68,23 @@ class AbstractItemView(QtWidgets.QAbstractItemView):
     def set_model(self, model):
         self.setModel(model)
 
-    def set_delegate(self, delegate, column=None, row=None):
+    def set_delegate(self,
+                     delegate,
+                     column: Optional[int] = None,
+                     row: Optional[int] = None,
+                     persistent: bool = False):
         if column is not None:
             self.setItemDelegateForColumn(column, delegate)
+            if persistent:
+                model = self.model()
+                for i in range(0, model.rowCount()):
+                    self.openPersistentEditor(model.index(i, column))
         elif row is not None:
             self.setItemDelegateForRow(row, delegate)
+            if persistent:
+                model = self.model()
+                for i in range(0, model.columnCount()):
+                    self.openPersistentEditor(model.index(row, i))
         else:
             self.setItemDelegate(delegate)
 
@@ -87,7 +99,7 @@ class AbstractItemView(QtWidgets.QAbstractItemView):
         else:
             self.selectAll()
 
-    def set_table_color(self, color):
+    def set_table_color(self, color: str):
         self.setStyleSheet(f"QHeaderView::section {{ background-color:{color} }}")
 
     def current_index(self) -> Optional[int]:
