@@ -310,6 +310,7 @@ def test_gridlayout():
 
 def test_groupbox():
     widget = widgets.GroupBox()
+    widget.set_title("test")
     ly = widgets.BoxLayout("horizontal")
     widget.set_layout(ly)
     ly += widgets.RadioButton("+=")
@@ -362,8 +363,14 @@ def test_label():
     label = widgets.Label()
     label.set_image("")
     label.set_text("testus")
+    with pytest.raises(ValueError):
+        label.set_text_format("test")
     label.set_alignment(horizontal="left", vertical="top")
+    label.set_alignment(vertical="bottom")
     label.set_text_interaction("by_mouse")
+    expected = ['by_mouse', 'like_text_editor', 'like_text_browser']
+    assert label.get_text_interaction() == expected
+    label.allow_links()
     with pytest.raises(ValueError):
         label.set_text_interaction("test")
     # assert label.get_text_interaction() == "by_mouse"
@@ -457,6 +464,8 @@ def test_mainwindow():
     window.toggle_fullscreen()
     window.toggle_fullscreen()
     window.add_toolbar(widgets.ToolBar())
+    with pytest.raises(ValueError):
+        window.add_toolbar(widgets.ToolBar(), position="test")
     assert len(window.get_toolbars()) == 1
     assert len(window.get_docks()) == 1
     window.remove_dockwidgets([w])
@@ -469,6 +478,7 @@ def test_mainwindow():
         pickle.dump(window, jar)
     with open("data.pkl", "rb") as jar:
         window = pickle.load(jar)
+    window.set_icon(None)
 
 
 def test_mdiarea():
@@ -522,13 +532,15 @@ def test_menubar():
 
 
 def test_messagebox():
-    widget = widgets.MessageBox()
+    widget = widgets.MessageBox(buttons=["reset"])
     widget.set_icon("warning")
     widget.set_icon("mdi.timer")
     widget.add_button("ok")
     widget.set_text_format("rich")
     with pytest.raises(ValueError):
         widget.set_text_format("test")
+    with pytest.raises(ValueError):
+        widget.add_button("test")
     assert widget.get_text_format() == "rich"
     widget.get_standard_buttons()
 
@@ -547,6 +559,9 @@ def test_plaintextedit():
     widget.scroll_to_top()
     widget.scroll_to_bottom()
     widget.set_value("test")
+    widget.set_wrap_mode("anywhere")
+    with pytest.raises(ValueError):
+        widget.set_wrap_mode("test")
     assert widget.get_value() == "test"
     widget += "append"
     with open("data.pkl", "wb") as jar:
@@ -575,8 +590,10 @@ def test_progressdialog():
 
 def test_pushbutton():
     widget = widgets.PushButton("Test", callback=print)
+    widget.set_text("test")
     widget.set_disabled()
     widget.set_enabled()
+    assert widget.get_value() is False
     widget.set_icon("mdi.timer")
     widget.set_style_icon("close")
     with open("data.pkl", "wb") as jar:
@@ -714,8 +731,9 @@ def test_styleoptionslider():
 
 def test_tabwidget():
     widget = widgets.TabWidget(detachable=True)
-    widget.add_tab(widgets.Widget(), "mdi.timer")
-    widget.insert_tab(0, widgets.Widget(), "test", "mdi.timer")
+    widget.add_tab(widgets.Widget(), "mdi.timer", show=True)
+    widget.set_document_mode(True)
+    widget.insert_tab(0, widgets.Widget(), "test", "mdi.timer", show=True)
     assert len(widget) == 2
     w = widgets.Widget()
     widget.add_tab(w, "test", "mdi.timer")
@@ -756,6 +774,7 @@ def test_textedit():
     widget.scroll_to_bottom()
     widget.set_disabled()
     widget.set_color("black")
+    widget.set_text_color("red")
     with open("data.pkl", "wb") as jar:
         pickle.dump(widget, jar)
     with open("data.pkl", "rb") as jar:
@@ -936,8 +955,8 @@ def test_treeview():
     model.add("test")
     widget.setModel(model)
     widget.set_delegate(widgets.StyledItemDelegate())
-    widget.set_delegate(widgets.StyledItemDelegate(), column=0)
-    widget.set_delegate(widgets.StyledItemDelegate(), row=0)
+    widget.set_delegate(widgets.StyledItemDelegate(), column=0, persistent=True)
+    widget.set_delegate(widgets.StyledItemDelegate(), row=0, persistent=True)
     widget.toggle_select_all()
     widget.toggle_select_all()
     model.update_row(0)
@@ -964,6 +983,7 @@ def test_treewidgetitem():
 
 def test_widget():
     widget = widgets.Widget()
+    widget.set_tooltip("test")
     layout = widgets.BoxLayout()
     widget.set_layout(layout)
     with open("data.pkl", "wb") as jar:
